#
# spec file for package civetweb
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         soname  1_15_0
%define         _libname libcivetweb

Name:           civetweb
Summary:        A C/C++ web server
License:        MIT
Group:          Productivity/Networking/Web/Servers
Version:        1.15
Release:        bp155.3.13
URL:            https://github.com/civetweb/civetweb
Source0:        https://github.com/civetweb/civetweb/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        civetweb.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel

%description
civetweb is a C/C++ embeddable web server with optional CGI, SSL and Lua support.

%package -n %{_libname}%{soname}
Summary:        Shared Object for applications that use %{name} embedded
Group:          Productivity/Networking/Web/Servers

%description -n %{_libname}%{soname}
This package contains the shared library required by applications that
are using %{name}'s embeddable API to provide web services.

%package -n %{_libname}-cpp%{soname}
Summary:        Shared Object for applications that use %{name} embedded
Group:          Productivity/Networking/Web/Servers

%description -n %{_libname}-cpp%{soname}
This package contains the shared library required by applications that
are using %{name}'s embeddable API to provide web services. 

%package devel
Summary:        Header files and development libraries for %{name}
Group:          Productivity/Networking/Web/Servers
Requires:       %{_libname}%{soname} = %{version}-%{release}
Requires:       %{_libname}-cpp%{soname} = %{version}-%{release}

%description devel
This package contains the header files and development libraries
for %{name}. If you like to develop programs embedding %{name} on them,
you will need to install %{name}-devel and check %{name}'s API at its
comprisable header file.

%prep
%setup -q

install -pm0644  %{SOURCE1} .

#we dont need github files
rm -rf .github
rm .git* .clan*

%build
rm -rf build
%cmake -DWITH_ALL=1 \
       -DCIVETWEB_BUILD_TESTING=OFF \
       -DCIVETWEB_ENABLE_CXX=ON \
       -DCIVETWEB_ENABLE_SSL_DYNAMIC_LOADING=OFF

%cmake_build %{?_smp_mflags}

%install
%cmake_install

%post -n %{_libname}%{soname} -p /sbin/ldconfig
%postun -n %{_libname}%{soname} -p /sbin/ldconfig

%post -n %{_libname}-cpp%{soname} -p /sbin/ldconfig
%postun -n %{_libname}-cpp%{soname} -p /sbin/ldconfig

%files
%doc %{name}.conf
%license LICENSE.md
%{_bindir}/%{name}

%files -n %{_libname}%{soname}
%{_libdir}/lib%{name}.so.*

%files -n %{_libname}-cpp%{soname}
%{_libdir}/lib%{name}-cpp.so.*

%files devel
%{_includedir}/%{name}.h
%{_includedir}/CivetServer.h
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}-cpp.so

%dir %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/*cmake

%changelog
* Thu May  5 2022 Marcus Meissner <meissner@suse.com>
- do not load libcrypto/libssl dynamically, just link against them (bsc#1199047)
* Fri Oct 22 2021 Axel Braun <axel.braun@gmx.de>
- version 1.15
  * Security update boo#1191938
  * New configuration for URL decoding
  * Sanitize filenames in handle form
  * Example “embedded_c.c”: Do not overwrite files (possible security issue)
  * Remove obsolete examples
  * Remove “experimental” label for some features
  * Remove MG_LEGACY_INTERFACE that have been declared obsolete in 2017 or earlier
  * Modifications to build scripts, required due to changes in the test environment
  * Unix domain socket support fixed
  * Fixes for NO_SSL_DL
  * Fixes for some warnings / static code analysis
* Mon May 10 2021 Perry Werneck <perry.werneck@gmail.com>
- Enabling cmake control file and cpp library.
* Sun May  9 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.14
  * Change SSL default setting to use TLS 1.2 as minimum (set config if you need an earlier version)
  * Add local_uri_raw field (not sanitized URI) to request_info
  * Additional API functions and a callback after closing connections
  * Allow mbedTLS as OpenSSL alternative (basic functionality)
  * Add OpenSSL 3.0 support (OpenSSL 3.0 Alpha 13)
  * Support UNIX/Linux domain sockets
  * Fuzz tests and ossfuzz integration
  * Compression for websockets
  * Restructure some source files
  * Improve documentation
  * Fix HTTP range requests
  * Add some functions for Lua scripts/LSP
  * Build system specific fixes (CMake, MinGW)
  * Update 3rd party components (Lua, lfs, sqlite)
  * Allow Lua background script to use timers, format and filter logs
  * Remove WinCE code
  * Update version number
* Wed Nov  4 2020 Axel Braun <axel.braun@gmx.de>
- version 1.13
  * Add arguments for CGI interpreters
  * Support multiple CGi interpreters
  * Buffering HTTP response headers, including API functions mg_response_header_* in C and Lua
  * Additional C API functions
  * Fix some memory leaks
  * Extended use of atomic operations (e.g., for server stats)
  * Add fuzz tests
  * Set OpenSSL 1.1 API as default (from 1.0)
  * Add Lua 5.4 support and deprecate Lua 5.1
  * Provide additional Lua API functions
  * Fix Lua websocket memory leak when closing the server
  * Remove obsolete "file in memory" implementation
  * Improvements and fixes in documentation
  * Fixes from static source code analysis
  * Additional unit tests
  * Various small bug fixes
  * Experimental support for some HTTP2 features (not ready for production)
  * Experimental support for websocket compression
  * Remove legacy interfaces declared obsolete since more than 3 years
* Fri Jul 10 2020 Axel Braun <axel.braun@gmx.de>
- version 1.12
  * fix-libpath.patch removed
  * See https://github.com/civetweb/civetweb/releases/tag/v1.12 for detailed changelog
* Thu Oct 31 2019 Ismail Dönmez <idonmez@suse.com>
- Add fix-libpath.patch to fix library install directory
* Sat Dec 22 2018 Axel Braun <axel.braun@gmx.de>
- Initial build at version 1.11.
  Thanks to malcolmlewis for helping with the specfile
